/****************************************************************************
 * (c) 2018 softwareentwicklung-als-prozess.de
 * Funktionalitaet:
 * Helligkeit mit einem LDR messen und ueber i2c auf verschiedenen Ausgaben anzeigen
 ***************************************************************************/
// Includes -----------------------------------------------------------------
#include "ldr.h"
#include "i2clcd.h"
#include "ledcontrol.h"
#include "sevseg.h"
#include "i2cdac.h"
#include "i2c_adressen.h"

// Defines -------------------------------------------------------------------
#define BITS_PRO_LED 311 // Experimentell ermittelter Wert

// Variablen -----------------------------------------------------------------
int helligkeit = 0;

// interne Prototypen --------------------------------------------------------
static void ledoutput(int hell);
static void segoutput(int hell);
static void baroutput(int hell);

// Funktionen ----------------------------------------------------------------
void setup() 
{
  Serial.begin(9600);
  // LCD Ausgabe
  i2clcd_Setup();
  // LED Ausgabe
  LED_Setup();
  LED_AllOn();
  delay(500);
  LED_AllOff();
  delay(500);
  // Siebensegment Ausgabe
  SEG_Setup();
  SEG_AllOn();
  delay(500);
  SEG_AllOff();
  delay(500);
  // LED Bargraph
  DAC_Setup(I2C_BARGRAPH_DISPLAY);
  // Sensor 
  ldr_Setup();

}

void loop() 
{
  helligkeit = ldr_Read();  // helligkeit messen
  i2clcd_Write(helligkeit); // und ausgeben
  ledoutput(helligkeit);
  segoutput(helligkeit);    // ca. jede sekunde
  baroutput(helligkeit);
}

static void baroutput(int hell)
{
  int daclevel = hell / 10;

  switch(daclevel)
  {
    case 0:
      DAC_WriteValue(1 * BITS_PRO_LED);
      break;
    case 1:
      DAC_WriteValue(2 * BITS_PRO_LED);
      break;
    case 2:
      DAC_WriteValue(3 * BITS_PRO_LED);
      break;
    case 3:
      DAC_WriteValue(4 * BITS_PRO_LED);
      break;
    case 4:
      DAC_WriteValue(5 * BITS_PRO_LED);
      break;
    case 5:
      DAC_WriteValue(6 * BITS_PRO_LED);
      break;
    case 6:
      DAC_WriteValue(7 * BITS_PRO_LED);
      break;
    case 7:
      DAC_WriteValue(8 * BITS_PRO_LED);
      break;
    case 8:
      DAC_WriteValue(9 * BITS_PRO_LED);
      break;
    case 9:
      DAC_WriteValue(10 * BITS_PRO_LED);
      break;
  }
}

static void segoutput(int hell)
{
  int level = hell / 10;
  
  switch(level)
  {
    case 0:
      SEG_Direkt(ZIFF_0);
      break;
    case 1:
      SEG_Direkt(ZIFF_1);
      break;
    case 2:
      SEG_Direkt(ZIFF_2);
      break;
    case 3:
      SEG_Direkt(ZIFF_3);
      break;
    case 4:
      SEG_Direkt(ZIFF_4);
      break;
    case 5:
      SEG_Direkt(ZIFF_5);
      break;
    case 6:
      SEG_Direkt(ZIFF_6);
      break;
    case 7:
      SEG_Direkt(ZIFF_7);
      break;
    case 8:
      SEG_Direkt(ZIFF_8);
      break;
    case 9:
      SEG_Direkt(ZIFF_9);
      break;
  }
}

static void ledoutput(int hell)
{
  if  (hell == 0)
  {
    LED_Direkt((unsigned char)0x00);
  }
  if ((hell >= (int)0) && (hell < (int)12))
  {
    LED_Direkt((unsigned char)BIT0);
  }
  if ((hell > (int)12) && (hell < (int)25))
  {
    LED_Direkt((unsigned char)BIT1);
  }
  if ((hell > (int)25) && (hell < (int)37))
  {
    LED_Direkt((unsigned char)BIT2);
  }
  if ((hell > (int)37) && (hell < (int)50))
  {
    LED_Direkt((unsigned char)BIT3);
  }
  if ((hell > (int)50) && (hell < (int)62))
  {
    LED_Direkt((unsigned char)BIT4);
  }
  if ((hell > (int)62) && (hell < (int)75))
  {
    LED_Direkt((unsigned char)BIT5);
  }
  if ((hell > (int)75) && (hell < (int)87))
  {
    LED_Direkt((unsigned char)BIT6);
  }
  if ((hell > (int)87) && (hell < (int)100))
  {
    LED_Direkt((unsigned char)BIT7);
  }
}

